Improve this Doc

# Error: $compile:selmulti
Binding to Multiple Attribute

    Binding to the 'multiple' attribute is not supported. Element: {0}

## Description

Binding to the `multiple` attribute of `select` element is not supported since switching between multiple and single mode changes the `ngModel` object type from instance to array of instances which breaks the model semantics.

If you need to use different types of `select` elements in your template based on some variable, please use ngIf or ngSwitch directives to select one of them to be used at runtime.

Example with invalid usage:

    <select ng-model="some.model" multiple="{{mode}}"></select>

Example that uses ngIf to pick one of the `select` elements based on a variable:

    <select ng-if="mode == 'multiple'" ng-model="some.model" multiple></select>
    <select ng-if="mode != 'multiple'" ng-model="some.model"></select>